README
======

.. toctree::
   :maxdepth: 4
   :caption: Content

   README.md

.. toctree::
   :maxdepth: 2
   :glob:
   :titlesonly:
   :caption: Code documentation

   *biobroker*

.. toctree::
    :maxdepth: 2
    :glob:
    :titlesonly:
    :caption: Notebooks

    notebooks/**/*